% Code to accompany "Statistical Decision Properties of Imprecise 
% Trials Assessing COVID-19 Drugs"
% by Charles F. Manski and Aleksey Tetenov
% June 2020
% We thank Valentyn Litvin for helpful comments regarding the code.
%
% This script computes error probabilities for a specific scenario
% shown in Table 3.
% Runtime: ~10 minutes
% on a desktop with a 6-core 3.2GHz Intel Core i7-8700B CPU
% Memory usage: 600MB (in command-line mode)

clear all

% Use a faster RNG
rng(0,'simdTwister');

diary Table3.txt

K = 5;
N = [500 250 250 250 250]
MC = 100000000; 

tic
Dunnett_CV = dunnett_unequal(K,N,0.05);
toc

tic
P = [0.7500    0.8500    0.8000    0.7000    0.6500]
format long
[NO_ES,P_ES,NO_D,P_D] = nearopt_multiarm_specific(N,P,MC,Dunnett_CV)
toc
% Product of error probability and loss for each treatment:
P_ES.*(max(P)-P)
P_D.*(max(P)-P)

diary off
